# CHANGELOG

This project uses [towncrier](https://towncrier.readthedocs.io/) to generate changelogs. 

For more information, see the [raw release notes](doc/source/changelog.rst).

[Published release notes](https://fluent.docs.pyansys.com/version/stable/changelog.html) can be found in the online documentation.
